@@ -62,8 +62,9 @@ class DatabaseJobSource(object):
                     job.log_file.save(
                         'job-%s.log' % job.id, ContentFile(''), save=False)
                     job.save()
-                    transaction.commit()
                     json_data = json.loads(job.definition)
+                    json_data['target'] = device.hostname
+                    transaction.commit()
                     log_file = job.log_file
                     log_file.file.close()
                     log_file.open('wb')
@@ -94,3 +95,16 @@ class DatabaseJobSource(object):
 
     def jobCompleted(self, board_name):
         return deferToThread(self.jobCompleted_impl, board_name)
+
+    @transaction.commit_on_success()
+    def jobOobData_impl(self, board_name, key, value):
+        self.logger.info(
+            "oob data received for %s: %s: %s", board_name, key, value)
+        if key == 'dashboard-put-result':
+            device = Device.objects.get(hostname=board_name)
+            device.current_job.results_link = value
+            device.current_job.save()
+
+    def jobOobData(self, board_name, key, value):
+        return deferToThread(self.jobOobData_impl, board_name, key, value)
+
